@@ -270,6 +270,35 @@ def upl(ctx, archive, package):
                        "Visit %s to publish." % ctx.obj.url('packages/%s' %
                                                              package_id))
 
+@cli.command()
+def protocols():
+    '''List protocols within your manifest'''
+    try:
+        with click.open_file('manifest.json', 'r') as f:
+            try:
+                manifest = json.loads(f.read())
+            except ValueError:
+                click.echo("Error: Your manifest.json file is improperly formatted. "
+                           "Please double check your brackets and commas!")
+                return
+            if 'protocols' not in manifest.keys() or not manifest['protocols']:
+                click.echo("Your manifest.json file doesn't contain any protocols or"
+                           " is improperly formatted.")
+                return
+            else:
+                click.echo('\n{:^60}'.format("Protocols within this manifest:"))
+                click.echo('{:-^60}'.format(''))
+                [click.echo("%s%s\n%s" % (p['name'],
+                                          (" (" + p.get('display_name') + ")")
+                                          if p.get('display_name') else "",
+                                          ('{:-^60}'.format(""))))
+                 for p in manifest["protocols"]]
+
+    except IOError:
+        click.echo("The current directory does not contain a manifest.json file.")
+        return
+
+
 @cli.command()
 @click.pass_context
 @click.option("-i")
@@ -281,29 +310,37 @@ def packages(ctx, i):
 
     if response.status_code == 200:
         for pack in response.json():
-            if pack.get('owner'):
-                if pack['owner']['email'] == ctx.obj.email:
-                    package_names['yours'][str(pack['name']).lower().replace("com.%s." % ctx.obj.organization, "")] = str(pack['id'])
+            n = str(pack['name']).lower().replace("com.%s." % ctx.obj.organization, "")
+            latest = str(pack['latest_version']) if pack['latest_version'] else "-"
+            if pack.get('owner') and pack['owner']['email'] == ctx.obj.email:
+                package_names['yours'][n] = {}
+                package_names['yours'][n]['id'] = str(pack['id'])
+                package_names['yours'][n]['latest'] = latest
             else:
-                package_names['theirs'][str(pack['name']).lower().replace("com.%s." % ctx.obj.organization, "")] = str(pack['id'])
+                package_names['theirs'][n] = {}
+                package_names['theirs'][n]['id'] = str(pack['id'])
+                package_names['theirs'][n]['latest'] = latest
     if i:
         return dict(package_names['yours'].items() + package_names['theirs'].items())
     else:
         for category, packages in package_names.items():
             if category == "yours":
-                click.echo('\n{:^80}'.format("YOUR PACKAGES:"))
-                click.echo('{:^40}'.format("PACKAGE NAME") + "|" +
-                       '{:^40}'.format("PACKAGE ID"))
-                click.echo('{:-^80}'.format(''))
+                click.echo('\n{:^90}'.format("YOUR PACKAGES:\n"))
+                click.echo('{:^30}'.format("PACKAGE NAME") + "|" +
+                       '{:^30}'.format("PACKAGE ID")
+                       + "|" + '{:^30}'.format("LATEST PUBLISHED VERSION"))
+                click.echo('{:-^90}'.format(''))
             elif category == "theirs" and packages.values():
-                click.echo('\n{:^80}'.format("OTHER PACKAGES IN YOUR ORG:"))
-                click.echo('{:^40}'.format("PACKAGE NAME") + "|" +
-                           '{:^40}'.format("PACKAGE ID"))
-                click.echo('{:-^80}'.format(''))
-            for name, id in packages.items():
-                click.echo('{:<40}'.format(name) + "|" +
-                           '{:^40}'.format(id))
-                click.echo('{:-^80}'.format(''))
+                click.echo('\n{:^90}'.format("OTHER PACKAGES IN YOUR ORG:\n"))
+                click.echo('{:^30}'.format("PACKAGE NAME") + "|" +
+                           '{:^30}'.format("PACKAGE ID") + "|" +
+                           '{:^30}'.format("LATEST PUBLISHED VERSION"))
+                click.echo('{:-^90}'.format(''))
+            for name, p in packages.items():
+                click.echo('{:<30}'.format(name) + "|" +
+                           '{:^30}'.format(p['id']) + "|" +
+                           '{:^30}'.format(p['latest']))
+                click.echo('{:-^90}'.format(''))
 
 @cli.command("new-package")
 @click.argument('name')
@@ -334,7 +371,7 @@ def new_package(ctx, description, name):
 @click.option('--force', '-f', help="force delete a package without being prompted if you're sure", is_flag=True)
 @click.pass_context
 def delete_package(ctx, name, force):
-    '''Create a new empty protocol package'''
+    '''Delete an existing protocol package'''
     id = get_package_id(name)
     if id:
         if not force:
@@ -365,12 +402,12 @@ def projects(ctx, i):
         else:
             for cat, packages in proj_cats.items():
                 if cat == "reg":
-                    click.echo('\n{:^80}'.format("PROJECTS:"))
+                    click.echo('\n{:^80}'.format("PROJECTS:\n"))
                     click.echo('{:^40}'.format("PROJECT NAME") + "|" +
                                '{:^40}'.format("PROJECT ID"))
                     click.echo('{:-^80}'.format(''))
                 elif cat == "pilot" and packages.values():
-                    click.echo('\n{:^80}'.format("PILOT PROJECTS:"))
+                    click.echo('\n{:^80}'.format("PILOT PROJECTS:\n"))
                     click.echo('{:^40}'.format("PROJECT NAME") + "|" +
                                '{:^40}'.format("PROJECT ID"))
                     click.echo('{:-^80}'.format(''))
@@ -412,7 +449,7 @@ def new_project(ctx, name, dev):
 @click.option('--force', '-f', help="force delete a project without being prompted if you're sure", is_flag=True)
 @click.pass_context
 def delete_project(ctx, name, force):
-    '''Delete an existing package'''
+    '''Delete an existing project'''
     id = get_project_id(name)
     if id:
         if not force:
@@ -472,8 +509,12 @@ def analyze(ctx, file, test):
         try:
             protocol = json.loads(f.read())
         except ValueError:
-            click.echo("Error: Could not analyze since your manifest.json file is "
-                       "improperly formatted.")
+            click.echo("Error: The Autoprotocol you're trying to analyze is not "
+                       "properly formatted.  "
+                       "\nCheck that your manifest.json file is "
+                       "valid JSON \nand/or your script "
+                       "doesn't print anything other than pure Autoprotocol "
+                       "to standard out.")
             return
     response = \
         ctx.obj.post(
@@ -547,6 +588,7 @@ def preview(protocol_name):
 @click.argument('file', default='-')
 @click.pass_context
 def summarize(ctx, file):
+    """Summarize Autoprotocol as a list of plain English steps (WIP)"""
     with click.open_file(file, 'r') as f:
         try:
             protocol = json.loads(f.read())
@@ -672,7 +714,7 @@ def get_project_name(ctx, id):
 @click.pass_context
 def get_package_id(ctx, name):
     package_names = ctx.invoke(packages, i=True)
-    package_names = {k.lower(): v for k,v in package_names.items()}
+    package_names = {k.lower(): v['id'] for k,v in package_names.items()}
     package_id = package_names.get(name)
     if not package_id:
         package_id = name if name in package_names.values() else None
@@ -684,7 +726,7 @@ def get_package_id(ctx, name):
 
 @click.pass_context
 def get_package_name(ctx, id):
-    package_names = {v: k for k, v in ctx.invoke(packages, i=True).items()}
+    package_names = {v['id']: k for k, v in ctx.invoke(packages, i=True).items()}
     package_name = package_names.get(id)
     if not package_name:
         package_name = id if id in package_names.values() else None
